@@ -57,6 +57,9 @@ class GenericTray():
         self.menu = QMenu()
         self.menu._subitems = {}
         self.tray.setContextMenu(self.menu)
+        self.on_left_clicked = Observable()
+        self.on_right_clicked = Observable()
+        self.tray.activated.connect(self._right_or_left_click)
 
     def show(self):
         self.tray.show()
@@ -67,6 +70,11 @@ class GenericTray():
     def close(self):
         self.tray.hide()
 
+    def _right_or_left_click(self, reason):
+        if reason == QSystemTrayIcon.ActivationReason.Trigger:
+            self.on_left_clicked.notify_observers()
+        elif reason == QSystemTrayIcon.ActivationReason.Context:
+            self.on_right_clicked.notify_observers()
 
 class PyHtmlQtSimpleTray(GenericTray):
     def addAction(self, name_or_names, target):
